/*******************************************************************************
** CRoom.H
** Neverland Ranch
** 11/27/2003
** Class representing a 'Room' in the World.
*******************************************************************************/

// Prevent multiple inclusions.
#ifndef H_CROOM_H
#define H_CROOM_H

// Include relevant files.

// Standard library stuff.
#include <vector>
#include <string>

// Forward class decelerations.
class CObject;

// Structure to represent Room links.
struct SRoomLink
{
	std::string							mCmd;				// Command associated with this link.
	std::string							mRmName;			// Room name.
};

// The Room class.
class CRoom
{
public:
	// *structors.
	CRoom(std::string name, std::string desc, std::string details);
	~CRoom();

	// Adds a link.
	int									addLink(std::string cmd,
												std::string rmName);

	// Gets a linked Room by Command.
	std::string							getLink(std::string cmd);

	// Get functions.
	std::string							getName()		{ return mName;		}
	std::string							getDesc()		{ return mDesc;		}
	std::string							getDetails()	{ return mDetails;	}

private:
	// Name of this room.
	std::string							mName;

	// Simple description (printed when you enter a Room).
	std::string							mDesc;

	// Details (printed when you thoroughly examin a Room).
	std::string							mDetails;

	// Links to other Rooms.
	std::vector<SRoomLink>				mLinks;

	// Objects in this room.
	std::vector<CObject*>				mObjects;

};

#endif // H_CROOM_H